@@ -240,3 +240,14 @@ LANGUAGE C;
 CREATE OR REPLACE FUNCTION plpgsql_check_pragma(VARIADIC name text[])
 RETURNS integer AS 'MODULE_PATHNAME', 'plpgsql_check_pragma'
 LANGUAGE C VOLATILE;
+
+CREATE OR REPLACE FUNCTION plpgsql_profiler_functions_all()
+RETURNS TABLE(funcoid regprocedure,
+              exec_count int8,
+              total_time double precision,
+              avg_time double precision,
+              stddev_time double precision,
+              min_time double precision,
+              max_time double precision)
+AS 'MODULE_PATHNAME','plpgsql_profiler_functions_all_tb'
+LANGUAGE C STRICT;
