@@ -1,5 +1,6 @@
 load 'plpgsql';
 create extension if not exists plpgsql_check;
+set client_min_messages to notice;
 
 --
 -- check function statement tests
@@ -3994,6 +3995,8 @@ select longfx(10);
 
 select lineno, stmt_lineno, exec_stmts, source from plpgsql_profiler_function_tb('longfx');
 
+select funcoid, exec_count from plpgsql_profiler_functions_all();
+
 create table testr(a int);
 create rule testr_rule as on insert to testr do nothing;
 
