@@ -34,7 +34,8 @@ enum
 	PLPGSQL_CHECK_FORMAT_JSON,
 	PLPGSQL_SHOW_DEPENDENCY_FORMAT_TABULAR,
 	PLPGSQL_SHOW_PROFILE_TABULAR,
-	PLPGSQL_SHOW_PROFILE_STATEMENTS_TABULAR
+	PLPGSQL_SHOW_PROFILE_STATEMENTS_TABULAR,
+	PLPGSQL_SHOW_PROFILE_FUNCTIONS_ALL_TABULAR
 };
 
 enum
@@ -54,6 +55,14 @@ enum
 	PLPGSQL_CHECK_UNKNOWN
 };
 
+typedef enum
+{
+	PLPGSQL_CHECK_STMT_WALKER_PREPARE_PROFILE,
+	PLPGSQL_CHECK_STMT_WALKER_COUNT_EXEC_TIME,
+	PLPGSQL_CHECK_STMT_WALKER_PREPARE_RESULT,
+	PLPGSQL_CHECK_STMT_WALKER_COLLECT_COVERAGE
+} profiler_stmt_walker_mode;
+
 typedef struct PLpgSQL_stmt_stack_item
 {
 	PLpgSQL_stmt	   *stmt;
@@ -181,6 +190,8 @@ extern void plpgsql_check_put_profile(plpgsql_check_result_info *ri, Datum query
 	int cmds_on_row, int exec_count, int64 us_total, Datum max_time_array, Datum processed_rows_array, char *source_row);
 extern void plpgsql_check_put_profile_statement(plpgsql_check_result_info *ri, pc_queryid queryid, int stmtid, int parent_stmtid, const char *parent_note, int block_num, int lineno,
 	int64 exec_stmts, double total_time, double max_time, int64 processed_rows, char *stmtname);
+extern void plpgsql_check_put_profiler_functions_all_tb(plpgsql_check_result_info *ri, Oid funcoid, int64 exec_count,
+	double total_time, double avg_time, double stddev_time, double min_time, double max_time);
 
 /*
  * function from catalog.c
@@ -196,13 +207,6 @@ extern Oid plpgsql_check_pragma_func_oid(void);
  */
 extern void plpgsql_check_info_init(plpgsql_check_info *cinfo, Oid fn_oid);
 
-
-/*
- * functions from profiler.c
- */
-extern void plpgsql_check_profiler_shmem_startup(void);
-extern void plpgsql_check_profiler_show_profile(plpgsql_check_result_info *ri, plpgsql_check_info *cinfo);
-
 /*
  * functions from check_function.c
  */
@@ -302,6 +306,8 @@ extern Oid plpgsql_check_parse_name_or_signature(char *name_or_signature);
 extern bool plpgsql_check_profiler;
 extern int plpgsql_check_profiler_max_shared_chunks;
 
+extern void plpgsql_check_profiler_shmem_startup(void);
+
 extern Size plpgsql_check_shmem_size(void);
 extern void plpgsql_check_profiler_init_hash_tables(void);
 
@@ -310,8 +316,11 @@ extern void plpgsql_check_profiler_func_end(PLpgSQL_execstate *estate, PLpgSQL_f
 extern void plpgsql_check_profiler_stmt_beg(PLpgSQL_execstate *estate, PLpgSQL_stmt *stmt);
 extern void plpgsql_check_profiler_stmt_end(PLpgSQL_execstate *estate, PLpgSQL_stmt *stmt);
 
+extern void plpgsql_check_iterate_over_profile(plpgsql_check_info *cinfo, profiler_stmt_walker_mode mode,
+   plpgsql_check_result_info *ri, coverage_state *cs);
+
 extern void plpgsql_check_profiler_show_profile(plpgsql_check_result_info *ri, plpgsql_check_info *cinfo);
-extern void plpgsql_check_profiler_show_profile_statements(plpgsql_check_result_info *ri, plpgsql_check_info *cinfo, coverage_state *cs);
+extern void plpgsql_check_profiler_iterate_over_all_profiles(plpgsql_check_result_info *ri);
 
 extern void plpgsql_check_init_trace_info(PLpgSQL_execstate *estate);
 extern bool plpgsql_check_get_trace_info(PLpgSQL_execstate *estate, PLpgSQL_stmt *stmt, PLpgSQL_execstate **outer_estate, int *frame_num, int *level, instr_time *start_time);
@@ -346,7 +355,6 @@ extern void plpgsql_check_trace_assert_on_stmt_beg(PLpgSQL_execstate *estate, PL
 
 extern void plpgsql_check_set_stmt_group_number(PLpgSQL_stmt *stmt, int *group_numbers, int *parent_group_numbers, int sgn, int *cgn, int psgn);
 
-
 /*
  * variables from pragma.c
  */
@@ -355,7 +363,6 @@ extern void plpgsql_check_pragma_apply(PLpgSQL_checkstate *cstate, char *pragma_
 extern plpgsql_check_pragma_vector plpgsql_check_runtime_pragma_vector;
 extern bool plpgsql_check_runtime_pragma_vector_changed;
 
-
 /*
  * functions from plpgsql_check.c
  */
@@ -364,7 +371,6 @@ extern shmem_startup_hook_type prev_shmem_startup_hook;
 
 extern PLpgSQL_plugin **plpgsql_check_plugin_var_ptr;
 
-
 #if PG_VERSION_NUM > 110005
 
 #define PLPGSQL_BUILD_DATATYPE_4		1
